@@ -19,8 +19,8 @@ from .errors import LaspyException
 from .point import dims
 from .point.format import PointFormat, ExtraBytesParams
 from .point.record import PackedPointRecord
-from .vlrs.known import ExtraBytesStruct, ExtraBytesVlr
 from .vlrs import VLR
+from .vlrs.known import ExtraBytesStruct, ExtraBytesVlr
 from .vlrs.vlrlist import VLRList
 from . import __version__
 
@@ -553,9 +553,6 @@ class LasHeader:
                     header.offset_to_point_data - current_pos
                 )
             elif current_pos > header.offset_to_point_data:
-                print(
-                    current_pos, header.offset_to_point_data, header_size, header.vlrs
-                )
                 raise LaspyException("Incoherent offset to point data")
 
         header.are_points_compressed = is_point_format_compressed(point_format_id)
@@ -579,7 +576,20 @@ class LasHeader:
                     point_format.add_extra_dimension(extra_dim_info)
         header._point_format = point_format
 
-        if point_size != point_format.size:
+        if point_size > point_format.size:
+            # We have unregistered extra bytes
+            num_extra_bytes = point_size - point_format.size
+            point_format.dimensions.append(
+                dims.DimensionInfo(
+                    name="ExtraBytes",
+                    kind=dims.DimensionKind.UnsignedInteger,
+                    num_bits=8 * num_extra_bytes,
+                    num_elements=num_extra_bytes,
+                    is_standard=False,
+                    description="Un-registered ExtraBytes",
+                )
+            )
+        elif point_size < point_format.size:
             raise LaspyException(
                 f"Incoherent point size, "
                 f"header says {point_size} point_format created says {point_format.size}"
@@ -590,7 +600,7 @@ class LasHeader:
     def write_to(self, stream: BinaryIO, ensure_same_size: bool = False) -> None:
         """
         ensure_same_size: if true this function will raise an internal error
-        of the written header would not change the offset to point data
+        if the written header would change the offset to point data
         it originally had (meaning the file could become broken),
         Used when rewriting a header to update the file (new point count, mins, maxs, etc)
         """
